<?php
 /*
 Plugin Name: Zap mirror site by Wisy
 Plugin URI:  https://www.wisy.co.il/
 Description: Creates a mirror site for Zap.
 Version:     1.0.0
 Author:      Wisy
 Author URI:  https://www.wisy.co.il/
 Text Domain: woocommerce-zap
 */
 
 
 
 defined( 'ABSPATH' ) || exit; // Exit if accessed directly
 
 /** @class Zap_Mirror_Wisy_Integration */
 final class Zap_Mirror_Wisy_Integration {
 	
 	public $options;
	
 	/** The single instance of the class. */
 	protected static $_instance = null;
 	
 	
 	/**
 	 * Notices (array)
 	 * @var array
 	 */
 	public $notices = array();
 	
 	/**
 	 * Returns the *Singleton* instance of this class.
 	 *
 	 * @return Singleton The *Singleton* instance.
 	 */
 	public static function instance() {
 		if ( is_null( self::$_instance ) ) {
 			self::$_instance = new self();
 		}
 		return self::$_instance;
 	}
 	
 	/**
 	 * Constructor.
 	 */
 	protected function __construct() {
 		add_action( 'admin_init', array( $this, 'woocommerce_zap_check_extensions' ) );
 		add_action( 'admin_init', array( $this, 'woocommerce_zap_page_init' ) );
 		add_action( 'admin_notices', array( $this, 'woocommerce_zap_admin_notices' ) );
 		add_action( 'woocommerce_product_data_tabs', array( $this, 'woocommerce_zap_add_product_data_tab' ) );
 		add_action( 'woocommerce_product_data_panels', array( $this, 'woocommerce_zap_add_product_data_panel' ) );
 		add_action( 'woocommerce_process_product_meta', array( $this, 'woocommerce_zap_process_product_meta' ) );
 		add_action( 'plugins_loaded', array( $this, 'woocommerce_zap_load_plugin_textdomain' ) );
 		add_action( 'admin_menu', array( $this, 'woocommerce_zap_menu' ) );
		add_filter( 'template_include', 						array( $this, 'woocommerce_zap_template_loader' ), 0 );
 	}
 	
 	/**
 	 * Checks the environment for compatibility problems.
 	 *
 	 * @return void
 	 */
 	public function woocommerce_zap_check_extensions() {
 		
 		if ( is_admin() && current_user_can( 'activate_plugins' ) && ! is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
 			$class = 'notice notice-error is-dismissible';
 			$message = __( 'This plugin requires <a href="https://wordpress.org/plugins/woocommerce/">WooCommerce</a> to be active.', 'woocommerce-zap' );
 			$this->woocommerce_zap_add_admin_notice( $class, $message );
 			// Deactivate the plugin
 			deactivate_plugins( __FILE__ );
 			return;
 		}
 		
 		if ( ! class_exists( 'SimpleXMLElement' ) ) {
 			$class = 'notice notice-error is-dismissible';
 			$message = __( 'The SimpleXMLElement extension could not be found. Please ask your host to install this extension.', 'woocommerce-zap' );
 			$this->woocommerce_zap_add_admin_notice( $class, $message );
 		}
 		$php_version = phpversion();
 		$required_php_version = '5.3';
 		if ( version_compare( $required_php_version, $php_version, '>' ) ) {
 			$class = 'notice notice-warning is-dismissible';
 			$message = sprintf( __( 'Your server is running PHP version %1$s but some features requires at least %2$s.', 'woocommerce-zap' ), $php_version, $required_php_version );
 			$this->woocommerce_zap_add_admin_notice( $class, $message );
 		}
 	}
 	
 	
 	/**
 	 * Localization.
 	 */
 	public function woocommerce_zap_load_plugin_textdomain() {
 		load_plugin_textdomain( 'woocommerce-zap', false, basename( dirname( __FILE__ ) ) . '/lang' );
 	}
 	
 	/**
 	 * Get the plugin url.
 	 *
 	 * @return string
 	 */
 	public function woocommerce_zap_plugin_url() {
 		return untrailingslashit( plugins_url( '/', __FILE__ ) );
 	}
 	
 	/**
 	 * Get the plugin path.
 	 *
 	 * @return string
 	 */
 	public function woocommerce_zap_plugin_path() {
 		return untrailingslashit( plugin_dir_path( __FILE__ ) );
 	}
 	
 	/**
 	 * Returns current plugin version.
 	 *
 	 * @return string Plugin version
 	 */
 	protected function woocommerce_zap_get_version() {
 		if ( ! function_exists( 'woocommerce_zap_get_plugins' ) ) {
 			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
 		}
 		$plugin_folder = get_plugins( '/' . plugin_basename( dirname( __FILE__ ) ) );
 		$plugin_file = basename( __FILE__ );
 		return $plugin_folder[ $plugin_file ]['Version'];
 	}
	
	
 	/**
 	 * Add admin notices.
 	 *
 	 * @param string $class
 	 * @param string $message
 	 * @return void
 	 */
 	public function woocommerce_zap_add_admin_notice( $class, $message ) {
 		$this->notices[] = array(
 			'class'   => $class,
 			'message' => $message
 		);
 	}
 	
 	
 	/**
 	 * Notices function.
 	 */
 	public function woocommerce_zap_admin_notices() {
 		foreach ( (array) $this->notices as $notice ) {
 			echo '<div class="' . esc_attr( $notice['class'] ) . '"><p><b>' . __( 'CeTu – Zap Mirror Site for WooCommerce', 'woocommerce-zap' ) . ': </b>';
 			echo wp_kses( $notice['message'], array( 'a' => array( 'href' => array() ) ) );
 			echo '</p></div>';
 		}
 	}
 	
 	/**
 	 * Add Woocommerce zap product tab.
 	 *
 	 * @param array $tabs
 	 * @return array
 	 */
 	public function woocommerce_zap_add_product_data_tab( $tabs ) {
 		$tabs['woocommerce_zap'] = array(
 			'label' => __( 'Zap Settings', 'woocommerce-zap' ),
 			'target' => 'woocommerce_zap_product_data',
 			'priority' => 99,
 			'class' => ''
 		);
 		
 		return $tabs;
 	}
 	
 	/**
 	 * Contents of the Woocommerce zap settings product tab.
 	 */
 	public function woocommerce_zap_add_product_data_panel() {
 		global $post;
 		?><div id="woocommerce_zap_product_data" class="panel woocommerce_options_panel hidden">
 			<div class="options_group">
 				<?php
 				do_action( 'woocommerce_zap_mirror_before_options' );
 				
 				woocommerce_wp_checkbox( array(
 					'id' 				=> '_woocommerce_zap_disable',
 					'label' 			=> __( 'Hide Product', 'woocommerce-zap' )
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_product_name',
 					'label' 			=> __( 'Product Name', 'woocommerce-zap' ),
 					'type' 				=> 'text',
 					'description' 		=> __( 'Maximum 40 characters', 'woocommerce-zap' )
 				) );
				
				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_product_code',
 					'label' 			=> __( 'Product Code', 'woocommerce-zap' ),
 					'type' 				=> 'text'
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_product_model',
 					'label' 			=> __( 'Product Model', 'woocommerce-zap' ),
 					'type' 				=> 'text',
 					'description' 		=> __( 'Optional', 'woocommerce-zap' )
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_product_catalog_number',
 					'label' 			=> __( 'Product Catalog Number', 'woocommerce-zap' ),
 					'type' 				=> 'text'
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_product_catalog_number',
 					'value'				=> 'ILS',
 					'label' 			=> __( 'Currency', 'woocommerce-zap' ),
 					'type' 				=> 'text',
 					'custom_attributes' => array(
 						'disabled' => 'disabled'
 					)
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_product_price',
 					'label' 			=> __( 'Price', 'woocommerce-zap' ),
 					'type' 				=> 'number',
 					'description' 		=> __( 'Digits only', 'woocommerce-zap' ),
 					'custom_attributes'	=> array(
 						'step' 	=> 'any',
 						'min' 	=> '0'
 					)
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_shipment',
 					'label' 			=> __( 'Shipping Costs', 'woocommerce-zap' ),
 					'type' 				=> 'number',
 					'description' 		=> __( 'Digits only', 'woocommerce-zap' ),
 					'custom_attributes'	=> array(
 						'step' 	=> 'any',
 						'min' 	=> '0'
 					)
 				) );
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_size',
 					'label' 			=> __( 'Size', 'woocommerce-zap' ),
 					'type' 				=> 'text',
 					'description' 		=> __( 'Size of the product', 'woocommerce-zap' )
 				) );
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_delivery',
 					'label' 			=> __( 'Delivery Time', 'woocommerce-zap' ),
 					'type' 				=> 'number',
 					'description' 		=> __( 'Digits only', 'woocommerce-zap' ),
 					'custom_attributes'	=> array(
 						'step' 	=> 'any',
 						'min' 	=> '0'
 					)
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_manufacturer',
 					'label' 			=> __( 'Manufacturer', 'woocommerce-zap' ),
 					'type' 				=> 'text',
 					'description' 		=> __( 'Should also appear in product\'s name', 'woocommerce-zap' )
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_warranty',
 					'label' 			=> __( 'Warranty', 'woocommerce-zap' ),
 					'type' 				=> 'text'
 				) );
 				
 				woocommerce_wp_text_input( array(
 					'id' 				=> '_woocommerce_zap_image',
 					'label' 			=> __( 'Image', 'woocommerce-zap' ),
 					'type' 				=> 'text'
 				) );
 				
 				woocommerce_wp_textarea_input( array(
 					'id' 				=> '_woocommerce_zap_product_description',
 					'rows'				=> 5,
 					'style' 			=> 'height: auto;',
 					'label' 			=> __( 'Product Description', 'woocommerce-zap' ),
 					'description' 		=> __( 'Maximum 255 characters', 'woocommerce-zap' ),
 					'custom_attributes'	=> array(
 						'maxlength' => '255'
 					)
 				) );
 				
 				do_action( 'woocommerce_zap_mirror_after_options' );
 				?>
 				<?php /*?><p class="form-field">
 					<label for="_woocommerce_zap_product_image"><?php _e( 'Image', 'woo-zap-mirror' ); ?></label>
 					<img src="<?php echo has_post_thumbnail() ? get_the_post_thumbnail_url( $post->ID, 'shop_thumbnail' ) : wc_placeholder_img_src(); ?>" id="_woocommerce_zap_product_image" />
 				</p><?php */?>
 			</div>
 		</div><?php
 	}
 	/**
 	 * Save Woocommerce zap settings.
 	 *
 	 * @param int $post_id
 	 * @return void
 	 */
 	public function woocommerce_zap_process_product_meta( $post_id ) {
 		if ( ! empty( $_POST['_woocommerce_zap_disable'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_disable', 'yes' );
 		} else {
 			update_post_meta( $post_id, '_woocommerce_zap_disable', '' );
 		}
 		if ( isset( $_POST['_woocommerce_zap_product_name'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_product_name', wc_clean( mb_substr( $_POST['_woocommerce_zap_product_name'], 0, 40, "utf-8" ) ) );
 		}
		if ( isset( $_POST['_woocommerce_zap_product_code'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_product_code', wc_clean( mb_substr( $_POST['_woocommerce_zap_product_code'], 0, 40, "utf-8" ) ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_product_model'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_product_model', wc_clean( $_POST['_woocommerce_zap_product_model'] ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_product_description'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_product_description', wc_clean( mb_substr( $_POST['_woocommerce_zap_product_description'], 0, 255, "utf-8" ) ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_product_catalog_number'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_product_catalog_number', wc_clean( $_POST['_woocommerce_zap_product_catalog_number'] ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_product_price'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_product_price', wc_clean( $_POST['_woocommerce_zap_product_price'] ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_shipment'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_shipment', wc_clean( $_POST['_woocommerce_zap_shipment'] ) );
 		}
		if ( isset( $_POST['_woocommerce_zap_size'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_size', wc_clean( $_POST['_woocommerce_zap_size'] ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_delivery'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_delivery', wc_clean( $_POST['_woocommerce_zap_delivery'] ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_manufacturer'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_manufacturer', wc_clean( $_POST['_woocommerce_zap_manufacturer'] ) );
 		}
 		if ( isset( $_POST['_woocommerce_zap_warranty'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_warranty', wc_clean( $_POST['_woocommerce_zap_warranty'] ) );
 		}
 		
 		if ( isset( $_POST['_woocommerce_zap_image'] ) ) {
 			update_post_meta( $post_id, '_woocommerce_zap_image', wc_clean( $_POST['_woocommerce_zap_image'] ) );
 		}
 	}
	
	
	/**
 	 * Save Woocommerce zap Menu.
 	 *
 	 * @param int $post_id
 	 * @return void
 	 */
	 
 	public function woocommerce_zap_menu() {
 		add_menu_page( __( 'Zap mirror','woocommerce-zap'), __( 'Zap mirror','woocommerce-zap'), 'manage_options', 'woocommerce-zap-settings.php', array( $this, 'woocommerce_zap_admin_page'), 'dashicons-tickets', 6  );
 	}
 	
 	public function woocommerce_zap_admin_page(){
 		// Set class property
         $this->options = get_option( 'woocommerce_zap_options' );
         ?>
         <div class="wrap">
             <h1><?php _e( 'Cetu Zap Mirror Settings','woocommerce-zap'); ?></h1>
             <form method="post" action="options.php">
             <?php
                 // This prints out all hidden setting fields
                 settings_fields( 'woocommerce_zap_option_group' );
                 do_settings_sections( 'woocommerce-zap-setting-admin' );
                 submit_button();
             ?>
             </form>
         </div>
 		<?php
 	}
 	
 	/**
      * Register and add settings fields
      */
     public function woocommerce_zap_page_init()
     {        
         register_setting(
             'woocommerce_zap_option_group', // Option group
             'woocommerce_zap_options', // Option name
             array( $this, 'woocommerce_zap_sanitize' ) // Sanitize
         );
         add_settings_section(
             'woocommerce_zap_setting_section_id', // ID
             __('General Settings','woocommerce-zap'), // Title
             array( $this, 'woocommerce_zap_print_section_info' ), // Callback
             'woocommerce-zap-setting-admin' // Page
         );  
         /*add_settings_field(
             'woocommerce_zap_licence_key', 
             __('License key','woocommerce-zap'), // Title 
             array( $this, 'woocommerce_zap_licence_key_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_setting_section_id' 
         ); */   
		 add_settings_field(
             'woocommerce_zap_mirror_page', 
             __('Mirror Site Page','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_mirror_page_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_setting_section_id'
         );  
         add_settings_field(
             'woocommerce_zap_hide_category', 
             __('Categories to skip','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_hide_category_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_setting_section_id'
         );  
 		
 		/*add_settings_field(
             'woocommerce_zap_use_zap_category', 
             __('Use zap categories','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_use_zap_category_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_setting_section_id'
         );*/
 		
 		add_settings_field(
             'woocommerce_zap_force_shipping_method', 
             __('Force shipping method','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_force_shipping_method_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_setting_section_id'
         );  
 		
 		add_settings_section(
             'woocommerce_zap_default_values', // ID
             __('Default values','woocommerce-zap'), // Title
             '',
             'woocommerce-zap-setting-admin' // Page
         );  
 		
 		add_settings_field(
             'woocommerce_zap_global_description', 
             __('Description','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_global_description_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_default_values'
         );
 		
 		add_settings_field(
             'woocommerce_zap_global_model', 
             __('Model','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_global_model_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_default_values'
         );
		add_settings_field(
             'woocommerce_zap_global_size', 
             __('Size','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_global_size_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_default_values'
         );
 		add_settings_field(
             'woocommerce_zap_global_delivery', 
             __('Delivery','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_global_delivery_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_default_values'
         );
 		add_settings_field(
             'woocommerce_zap_global_manufacturer', 
             __('Manufacturer','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_global_manufacturer_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_default_values'
         );
 		add_settings_field(
             'woocommerce_zap_global_warranty', 
             __('Warranty','woocommerce-zap'), 
             array( $this, 'woocommerce_zap_global_warranty_callback' ), 
             'woocommerce-zap-setting-admin', 
             'woocommerce_zap_default_values'
         );
 		 
 		 
     }
 	
 	
 	/**
      * Sanitize each setting field as needed
      *
      * @param array $input Contains all settings fields as array keys
      */
     public function woocommerce_zap_sanitize( $input )
     {
         $new_input = array();
         /*if( isset( $input['woocommerce_zap_licence_key'] ) )
             $new_input['woocommerce_zap_licence_key'] = sanitize_text_field( $input['woocommerce_zap_licence_key'] );*/
		if( isset( $input['woocommerce_zap_mirror_page'] ) )
             $new_input['woocommerce_zap_mirror_page'] = sanitize_text_field( $input['woocommerce_zap_mirror_page'] );
		
        if( isset( $input['woocommerce_zap_hide_category'] ) ) { 
			
			$input_array = implode(',',$input['woocommerce_zap_hide_category']);
			$new_input['woocommerce_zap_hide_category'] = sanitize_text_field( $input_array );
		}
 			
 		/*if( isset( $input['woocommerce_zap_use_zap_category'] ) )
             $new_input['woocommerce_zap_use_zap_category'] = absint( $input['woocommerce_zap_use_zap_category'] );*/
 			
 		if( isset( $input['woocommerce_zap_force_shipping_method'] ) )
             $new_input['woocommerce_zap_force_shipping_method'] = sanitize_text_field( $input['woocommerce_zap_force_shipping_method'] );
 			
 		if( isset( $input['woocommerce_zap_global_description'] ) )
             $new_input['woocommerce_zap_global_description'] = sanitize_text_field( $input['woocommerce_zap_global_description'] );
 			
 		if( isset( $input['woocommerce_zap_global_description_attribute'] ) )
             $new_input['woocommerce_zap_global_description_attribute'] = sanitize_text_field( $input['woocommerce_zap_global_description_attribute'] );
 		
 		if( isset( $input['woocommerce_zap_global_model'] ) )
             $new_input['woocommerce_zap_global_model'] = sanitize_text_field( $input['woocommerce_zap_global_model'] );
 			
 		if( isset( $input['woocommerce_zap_global_model_attribute'] ) )
             $new_input['woocommerce_zap_global_model_attribute'] = sanitize_text_field( $input['woocommerce_zap_global_model_attribute'] );
 		
 		if( isset( $input['woocommerce_zap_global_model_default'] ) )
             $new_input['woocommerce_zap_global_model_default'] = sanitize_text_field( $input['woocommerce_zap_global_model_default'] );
 		
		if( isset( $input['woocommerce_zap_global_size'] ) )
             $new_input['woocommerce_zap_global_size'] = sanitize_text_field( $input['woocommerce_zap_global_size'] );
		
		if( isset( $input['woocommerce_zap_global_size_attribute'] ) )
             $new_input['woocommerce_zap_global_size_attribute'] = sanitize_text_field( $input['woocommerce_zap_global_size_attribute'] );
 		
 		if( isset( $input['woocommerce_zap_global_size_default'] ) )
             $new_input['woocommerce_zap_global_size_default'] = sanitize_text_field( $input['woocommerce_zap_global_size_default'] );
			 	
 		if( isset( $input['woocommerce_zap_global_delivery'] ) )
             $new_input['woocommerce_zap_global_delivery'] = sanitize_text_field( $input['woocommerce_zap_global_delivery'] );
 			
 		if( isset( $input['woocommerce_zap_global_delivery_attribute'] ) )
             $new_input['woocommerce_zap_global_delivery_attribute'] = sanitize_text_field( $input['woocommerce_zap_global_delivery_attribute'] );
 		
 		if( isset( $input['woocommerce_zap_global_delivery_default'] ) )
             $new_input['woocommerce_zap_global_delivery_default'] = sanitize_text_field( $input['woocommerce_zap_global_delivery_default'] );
 		
 		if( isset( $input['woocommerce_zap_global_manufacturer'] ) )
             $new_input['woocommerce_zap_global_manufacturer'] = sanitize_text_field( $input['woocommerce_zap_global_manufacturer'] );
 			
 		if( isset( $input['woocommerce_zap_global_manufacturer_attribute'] ) )
             $new_input['woocommerce_zap_global_manufacturer_attribute'] = sanitize_text_field( $input['woocommerce_zap_global_manufacturer_attribute'] );
 		
 		if( isset( $input['woocommerce_zap_global_manufacturer_default'] ) )
             $new_input['woocommerce_zap_global_manufacturer_default'] = sanitize_text_field( $input['woocommerce_zap_global_manufacturer_default'] );
 			
 		if( isset( $input['woocommerce_zap_global_warranty'] ) )
             $new_input['woocommerce_zap_global_warranty'] = sanitize_text_field( $input['woocommerce_zap_global_warranty'] );
 			
 		if( isset( $input['woocommerce_zap_global_warranty_attribute'] ) )
             $new_input['woocommerce_zap_global_warranty_attribute'] = sanitize_text_field( $input['woocommerce_zap_global_warranty_attribute'] );
 		
 		if( isset( $input['woocommerce_zap_global_warranty_default'] ) )
             $new_input['woocommerce_zap_global_warranty_default'] = sanitize_text_field( $input['woocommerce_zap_global_warranty_default'] );
         return $new_input;
     }
     /** 
      * Print the Section text
      */
     public function woocommerce_zap_print_section_info()
     {
         print __('Enter your settings below:','woocommerce-zap');
     }
     /** 
      * Get the settings option array and print one of its values
      */
     /*public function woocommerce_zap_licence_key_callback()
     {
         printf(
             '<input type="text" id="woocommerce_zap_licence_key" name="woocommerce_zap_options[woocommerce_zap_licence_key]" value="%s" />
 			<p>%s</p>',
             isset( $this->options['woocommerce_zap_licence_key'] ) ? esc_attr( $this->options['woocommerce_zap_licence_key']) : '', __('Enter Licence key')
         );
     }*/
	 
	 /** 
      * Mirror page callback
      */
	  
	 public function woocommerce_zap_mirror_page_callback()
     {
 		$pages = get_pages();
 		//var_dump($shipping_methods);
 		
         printf(
             '<select id="woocommerce_zap_mirror_page" name="woocommerce_zap_options[woocommerce_zap_mirror_page]" >'
         );
 		foreach ($pages as $page) {
 			printf(
             '<option value="%s" %s >%s</option>',
 			$page->ID,
             $this->options['woocommerce_zap_mirror_page'] == $page->ID ? esc_attr('selected') : '',
 			$page->post_title
         );
 		}
 		printf(
             '</select><p>%s</p>',   __('This sets the zap mirror page of your site','woocommerce-zap')
 			);
     }
	 
     /** 
      * Hide category callback
      */
     public function woocommerce_zap_hide_category_callback()
     {
		 $selected_cat = explode(",",$this->options['woocommerce_zap_hide_category']);
         /*printf(
             '<input type="text" id="woocommerce_zap_hide_category" name="woocommerce_zap_options[woocommerce_zap_hide_category]" value="%s" /><p>%s</p>',
             isset( $this->options['woocommerce_zap_hide_category'] ) ? esc_attr( $this->options['woocommerce_zap_hide_category']) : '', __('a comma delimited list of category slugs .... slug1,slug2,slug3','woocommerce-zap')
         );*/
		 //print_r($this->options['woocommerce_zap_hide_category']);
		 echo '<div id="product_cat-all" class="tabs-panel">
					<ul id="zap-product_catchecklist" data-wp-lists="list:product_cat" class="categorychecklist form-no-clear" style="margin:0;">';
		 echo str_replace(
							'tax_input[product_cat]', 
							'woocommerce_zap_options[woocommerce_zap_hide_category]', 
							wp_terms_checklist(
								$this->options['woocommerce_zap_mirror_page'], 
								array(
									'selected_cats'	=> $selected_cat,
									'taxonomy' 		=> 'product_cat',
									'echo' 			=> false
								)
							)
						); 
		echo '</ul></div>';
     }
	 
	 
 	
 	/** 
      * Use zap category callback
      */
     /*public function woocommerce_zap_use_zap_category_callback()
     {
         printf(
             '<input type="checkbox" id="woocommerce_zap_use_zap_category" name="woocommerce_zap_options[woocommerce_zap_use_zap_category]" %s value="%s"  /><p>%s</p>',
 			isset( $this->options['woocommerce_zap_use_zap_category'] ) ? esc_attr('checked') : '',
             isset( $this->options['woocommerce_zap_use_zap_category'] ) ? 1 : 0, 
 			__('This will allow you to keep your site categories unchanged while presenting a 2 level category tree for zap','woocommerce-zap')
 			
         );
     }*/
 	
	
	/** 
      * Force Shipment method callback
      */
 	public function woocommerce_zap_force_shipping_method_callback()
     {
		 $delivery_zones = WC_Shipping_Zones::get_zones();
		foreach ((array) $delivery_zones as $key => $the_zone ) {
			//var_dump($the_zone['id']);
		  foreach ($the_zone['zone_locations'] as $zone_location) {
			  if($zone_location->code == 'IL') {
				  $default_zone = new WC_Shipping_Zone($the_zone['id']);
			  }
		  }
		
		}
		if(!$default_zone) {
			$default_zone = new WC_Shipping_Zone(0);
		}
		 
		 $shipping_methods = $default_zone->get_shipping_methods();
 		//$shipping_methods = WC()->shipping->get_shipping_methods();
 		//var_dump($shipping_methods);
         printf(
             '<select id="woocommerce_zap_force_shipping_method" name="woocommerce_zap_options[woocommerce_zap_force_shipping_method]" >'
         );
 		foreach ($shipping_methods as $shipping_method) { 
 			printf(
             '<option value="%s" %s >%s</option>',
 			$shipping_method->id,
             $this->options['woocommerce_zap_force_shipping_method'] == $shipping_method->id ? esc_attr('selected') : '',
 			$shipping_method->title
         );
 		}
 		printf(
             '</select><p>%s</p>',   __('Select the shipping method that will be used.','woocommerce-zap')
 			);
     }
 	
 	
 	/** 
      * Global description callback
      */
     public function woocommerce_zap_global_description_callback()
     {
         printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_description]" %s value=""  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_description'] == "" ? esc_attr('checked') : '',
 			__('Not Set','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_description]" %s value="long"  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_description'] == "long" ? esc_attr('checked') : '',
 			__('Use description','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_description]" %s value="short"  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_description'] == "short" ? esc_attr('checked') : '',
 			__('Use short product description','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_description]" %s value="attribute"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_description'] == "attribute" ? esc_attr('checked') : '',
 			__('Assign a product attribute','woocommerce-zap')
 			
         );
 		$attributes =  wc_get_attribute_taxonomies();
 		//var_dump($attributes);
 		
 		if($attributes) {
 			printf(
 				' <select id="woocommerce_zap_global_description_attribute" name="woocommerce_zap_options[woocommerce_zap_global_description_attribute]" >'
 			);
 			foreach ($attributes as $attribute) {
 				printf(
 				'<option value="%s" %s >%s</option>',
 				$attribute->attribute_name,
 				$this->options['woocommerce_zap_global_description_attribute'] == $attribute->attribute_name ? esc_attr('selected') : '',
 				$attribute->attribute_label
 			);
 			}
 		}
 		printf(
             '</select>'
 			);
     }
 	
 	
 	/** 
      * Model callback
      */
     public function woocommerce_zap_global_model_callback()
     {
         printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_model]" %s value=""  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_model'] == "" ? esc_attr('checked') : '',
 			__('Not Set','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_model]" %s value="text"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_model'] == "text" ? esc_attr('checked') : '',
 			__('Default value','woocommerce-zap')
 			
         );
 		printf(
             '<input type="text" id="woocommerce_zap_global_model_default" name="woocommerce_zap_options[woocommerce_zap_global_model_default]" value="%s" /><br>',
             isset( $this->options['woocommerce_zap_global_model_default'] ) ? esc_attr( $this->options['woocommerce_zap_global_model_default']) : ''
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_model]" %s value="attribute"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_model'] == "attribute" ? esc_attr('checked') : '',
 			__('Assign a product attribute','woocommerce-zap')
 			
         );
 		$attributes =  wc_get_attribute_taxonomies();
 		//var_dump($attributes);
 		
 		if($attributes) { //var_dump($attributes);
 			printf(
 				' <select id="woocommerce_zap_global_model_attribute" name="woocommerce_zap_options[woocommerce_zap_global_model_attribute]" >'
 			);
 			foreach ($attributes as $attribute) {
				
 				printf(
 				'<option value="%s" %s >%s</option>',
 				$attribute->attribute_name,
 				$this->options['woocommerce_zap_global_model_attribute'] == $attribute->attribute_name ? esc_attr('selected') : '',
 				$attribute->attribute_label
 			);
 			}
 		}
 		printf(
             '</select>'
 			);
     }
 	
	/** 
      * Size callback
      */
     public function woocommerce_zap_global_size_callback()
     {
         printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_size]" %s value=""  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_size'] == "" ? esc_attr('checked') : '',
 			__('Not Set','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_size]" %s value="text"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_size'] == "text" ? esc_attr('checked') : '',
 			__('Default value','woocommerce-zap')
 			
         );
 		printf(
             '<input type="text" id="woocommerce_zap_global_size_default" name="woocommerce_zap_options[woocommerce_zap_global_size_default]" value="%s" /><br>',
             isset( $this->options['woocommerce_zap_global_size_default'] ) ? esc_attr( $this->options['woocommerce_zap_global_size_default']) : ''
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_size]" %s value="attribute"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_size'] == "attribute" ? esc_attr('checked') : '',
 			__('Assign a product attribute','woocommerce-zap')
 			
         );
 		$attributes =  wc_get_attribute_taxonomies();
 		//var_dump($attributes);
 		
 		if($attributes) {
 			printf(
 				' <select id="woocommerce_zap_global_size_attribute" name="woocommerce_zap_options[woocommerce_zap_global_size_attribute]" >'
 			);
 			foreach ($attributes as $attribute) {
 				printf(
 				'<option value="%s" %s >%s</option>',
 				$attribute->attribute_name,
 				$this->options['woocommerce_zap_global_size_attribute'] == $attribute->attribute_name ? esc_attr('selected') : '',
 				$attribute->attribute_label
 			);
 			}
 		}
 		printf(
             '</select>'
 			);
     }
 	
 	/** 
      * Delivery callback
      */
     public function woocommerce_zap_global_delivery_callback()
     {
         printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_delivery]" %s value=""  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_delivery'] == "" ? esc_attr('checked') : '',
 			__('Not Set','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_delivery]" %s value="text"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_delivery'] == "text" ? esc_attr('checked') : '',
 			__('Default value','woocommerce-zap')
 			
         );
 		printf(
             '<input type="text" id="woocommerce_zap_global_delivery_default" name="woocommerce_zap_options[woocommerce_zap_global_delivery_default]" value="%s" /><br>',
             isset( $this->options['woocommerce_zap_global_delivery_default'] ) ? esc_attr( $this->options['woocommerce_zap_global_delivery_default']) : ''
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_delivery]" %s value="attribute"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_delivery'] == "attribute" ? esc_attr('checked') : '',
 			__('Assign a product attribute','woocommerce-zap')
 			
         );
 		$attributes =  wc_get_attribute_taxonomies();
 		//var_dump($attributes);
 		
 		if($attributes) {
 			printf(
 				' <select id="woocommerce_zap_global_delivery_attribute" name="woocommerce_zap_options[woocommerce_zap_global_delivery_attribute]" >'
 			);
 			foreach ($attributes as $attribute) {
 				printf(
 				'<option value="%s" %s >%s</option>',
 				$attribute->attribute_name,
 				$this->options['woocommerce_zap_global_delivery_attribute'] == $attribute->attribute_name ? esc_attr('selected') : '',
 				$attribute->attribute_label
 			);
 			}
 		}
 		printf(
             '</select>'
 			);
     }
 	
 	/** 
      * Manufacturer callback
      */
     public function woocommerce_zap_global_manufacturer_callback()
     {
         printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_manufacturer]" %s value=""  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_manufacturer'] == "" ? esc_attr('checked') : '',
 			__('Not Set','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_manufacturer]" %s value="text"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_manufacturer'] == "text" ? esc_attr('checked') : '',
 			__('Default value','woocommerce-zap')
 			
         );
 		printf(
             '<input type="text" id="woocommerce_zap_global_manufacturer_default" name="woocommerce_zap_options[woocommerce_zap_global_manufacturer_default]" value="%s" /><br>',
             isset( $this->options['woocommerce_zap_global_manufacturer_default'] ) ? esc_attr( $this->options['woocommerce_zap_global_manufacturer_default']) : ''
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_manufacturer]" %s value="attribute"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_manufacturer'] == "attribute" ? esc_attr('checked') : '',
 			__('Assign a product attribute','woocommerce-zap')
 			
         );
 		$attributes =  wc_get_attribute_taxonomies();
 		//var_dump($attributes);
 		
 		if($attributes) {
 			printf(
 				' <select id="woocommerce_zap_global_manufacturer_attribute" name="woocommerce_zap_options[woocommerce_zap_global_manufacturer_attribute]" >'
 			);
 			foreach ($attributes as $attribute) {
 				printf(
 				'<option value="%s" %s >%s</option>',
 				$attribute->attribute_name,
 				$this->options['woocommerce_zap_global_manufacturer_attribute'] == $attribute->attribute_name ? esc_attr('selected') : '',
 				$attribute->attribute_label
 			);
 			}
 		}
 		printf(
             '</select>'
 			);
     }
 	
 	/** 
      * Warranty callback
      */
     public function woocommerce_zap_global_warranty_callback()
     {
         printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_warranty]" %s value=""  /><label>%s</label><br>',
 			$this->options['woocommerce_zap_global_warranty'] == "" ? esc_attr('checked') : '',
 			__('Not Set','woocommerce-zap')
 			
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_warranty]" %s value="text"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_warranty'] == "text" ? esc_attr('checked') : '',
 			__('Default value','woocommerce-zap')
 			
         );
 		printf(
             '<input type="text" id="woocommerce_zap_global_warranty_default" name="woocommerce_zap_options[woocommerce_zap_global_warranty_default]" value="%s" /><br>',
             isset( $this->options['woocommerce_zap_global_warranty_default'] ) ? esc_attr( $this->options['woocommerce_zap_global_warranty_default']) : ''
         );
 		printf(
             '<input type="radio" name="woocommerce_zap_options[woocommerce_zap_global_warranty]" %s value="attribute"  /><label>%s</label>',
 			$this->options['woocommerce_zap_global_warranty'] == "attribute" ? esc_attr('checked') : '',
 			__('Assign a product attribute','woocommerce-zap')
 			
         );
		 
		 
 		$attributes =  wc_get_attribute_taxonomies();
 		//var_dump($attributes);
 		
 		if($attributes) {
 			printf(
 				' <select id="woocommerce_zap_global_warranty_attribute" name="woocommerce_zap_options[woocommerce_zap_global_warranty_attribute]" >'
 			);
 			foreach ($attributes as $attribute) {
 				printf(
 				'<option value="%s" %s >%s</option>',
 				$attribute->attribute_name,
 				$this->options['woocommerce_zap_global_warranty_attribute'] == $attribute->attribute_name ? esc_attr('selected') : '',
 				$attribute->attribute_label
 			);
 			}
 		}
 		printf(
             '</select>'
 			);
     }
	 
	 
	 /**
	 * Get products by term id.
	 *
	 * @param int $term_id
	 * @param array $exclude_ids
	 * @return WP_Query
	 */
	public function woocommerce_zap_get_products( $term_id, $exclude_ids = array() ) {
		$args = array(
			'post_type' 		=> 'product',
			'posts_per_page' 	=> -1,
			'tax_query' 		=> array(
				array(
					'taxonomy' 			=> 'product_cat',
					'field' 			=> 'term_id',
					'terms' 			=> $term_id,
					'include_children'	=> false,
					'operator' 			=> 'IN'
				)
			),
			'meta_query' => array(
				'relation' => 'OR',
				array(
					'key'     	=> '_woocommerce_zap_disable',
					'value'		=> 'yes',
					'compare' 	=> '!='
				),
				array(
					'key' 		=> '_woocommerce_zap_disable',
					'compare' 	=> 'NOT EXISTS'
				)
			)
		);
		
		/**
		 * Filters the arguments passed to each WP_Query instance.
		 */
		$args = apply_filters( 'woocommerce_zap_mirror_wp_query', $args, $term_id );
		
		/**
		 * Filters the arguments passed to a specific WP_Query instance.
		 */
		$args = apply_filters( "woocommerce_zap_mirror_wp_query_{$term_id}", $args );
		
		return new WP_Query( $args );
	}
	
	
	/**
	 * Get product categories.
	 *
	 * @param array $exclude_ids
	 * @return array
	 */
	public function woocommerce_zap_get_terms( $exclude_ids = array() ) {
		$args = array(
			'taxonomy' 		=> 'product_cat',
			'hide_empty' 	=> 0,
			'exclude_tree' 	=> $exclude_ids
		);
		
		/**
		 * Filters the arguments passed to the get_terms() function.
		 */
		$args = apply_filters( 'woocommerce_zap_mirror_get_terms', $args, $exclude_ids );
		
		//var_dump($args);
		return get_terms( $args );
	}
	 
	 
	 
	 /**
	 * Load zap mirror site.
	 *
	 * @param mixed $template
	 * @return string
	 */
	public function woocommerce_zap_template_loader( $template ) {
		$this->options = get_option( 'woocommerce_zap_options' );
		//print_r($this->options['woocommerce_zap_mirror_page']); die("hi");
		if ( is_page( $this->options['woocommerce_zap_mirror_page'] ) ) {
			// Tell WP Super Cache & W3 Total Cache to not cache requests
			define( 'DONOTCACHEPAGE', true );
			
			$this->woocommerce_zap_mirror_site();
			exit;
		}
		return $template;
	}
	/**
	 * Mirror Site handler.
	 */
	public function woocommerce_zap_mirror_site() {
		$this->options = get_option( 'woocommerce_zap_options' );
		$exclude_ids = array();
		if(isset($this->options['woocommerce_zap_hide_category']) && $this->options['woocommerce_zap_hide_category'] != "") {
			$exclude_ids = explode(',',$this->options['woocommerce_zap_hide_category']);
		}
		//print_r($exclude_ids); die("hi");
		
		// XML
		if ( $term_id = get_query_var( 'product_cat' ) ) {
			// Bail out prior to query initiation if term is excluded.
			if ( in_array( $term_id, $exclude_ids ) ) {
				wp_die( __( 'No categories found.', 'woocommerce-zap' ) );
			}
			
			$products = $this->woocommerce_zap_get_products( $term_id, $exclude_ids );
			if ( $products->have_posts() ) {
				$this->woocommerce_zap_create_xml( $products );
			} else {
				wp_die( __( 'No available products.', 'woocommerce-zap' ) );
			}
			
			return;
			
		// HTML Template
		} elseif ( $terms = $this->woocommerce_zap_get_terms( $exclude_ids ) ) {
			
			ob_start();
			foreach ( $terms as $term ) {
				$id		= $term->term_id;
				$pid	= $term->parent;
				$name	= esc_attr( $term->name );
				$url	= add_query_arg( 'product_cat', $term->term_id, get_permalink( $this->options['woocommerce_zap_mirror_page'] ) );
				echo "d.add({$id}, {$pid}, '{$name}', '{$url}');\n";
				// Indentation
				if ( $term !== end( $terms ) ) {
					echo "\t\t";
				}
			}
			$nodes = ob_get_clean();
			
			wc_get_template( 'zap-mirror.php', null, null, $this->woocommerce_zap_plugin_path() . '/templates/' );
			return;
		}
		
		wp_die( __( 'No categories found.', 'woocommerce-zap' ) );
	}
	/**
	 * Output XML.
	 *
	 * @param WP_Query $products
	 */
	public function woocommerce_zap_create_xml( $products ) {
		
		$this->options = get_option( 'woocommerce_zap_options' );
		header( "Content-Type: application/xml; charset=utf-8" );
		$xml = new SimpleXMLElement( '<?xml version="1.0" encoding="UTF-8"?><STORE></STORE>' );
		$xml->addAttribute( 'URL', home_url() );
		$xml->addAttribute( 'DATE', date_i18n( 'd/m/Y' ) );
		$xml->addAttribute( 'TIME', date_i18n( 'H:i:s' ) );
		$parent = $xml->addChild( 'PRODUCTS' );
		foreach ( $products->posts as $post ) {
			$product = wc_get_product( $post->ID );
			//var_dump($product); die('hi');
			$product_id = $product->ID;
			$apro_attr = $product->get_attribute('test2');
			$node = $parent->addchild( 'PRODUCT' );
			$node->addAttribute( 'NUM', $product->get_id() );
			$node->PRODUCT_URL 		= get_permalink($product->get_id() );
			if($product->get_meta( '_woocommerce_zap_product_name' )) {
				$node->PRODUCT_NAME 	= $product->get_meta( '_woocommerce_zap_product_name' );
			} else {
				$node->PRODUCT_NAME 	= $post->post_title;
			}
			if($product->get_meta( '_woocommerce_zap_product_code' )) {
				$node->PRODUCTCODE 	= $product->get_meta( '_woocommerce_zap_product_code' );
			} else {
				$node->PRODUCTCODE 	= $product->get_id();
			}
			if($product->get_meta( '_woocommerce_zap_product_model' )) {
				$node->MODEL 			= $product->get_meta( '_woocommerce_zap_product_model' );
			} else if($this->options['woocommerce_zap_global_model'] == 'attribute') {
				$node->MODEL 	= $product->get_attribute($this->options['woocommerce_zap_global_model_attribute']);
			} else if($this->options['woocommerce_zap_global_model'] == 'text') {
				$node->MODEL 	= $this->options['woocommerce_zap_global_model_default'];
			} else {
				$node->MODEL 	= "";
			}
			if($product->get_meta( '_woocommerce_zap_product_description' )) {
				$node->DETAILS 			= $product->get_meta( '_woocommerce_zap_product_description' );
			} else if($this->options['woocommerce_zap_global_description'] == 'attribute') {
				$node->DETAILS 	= $product->get_attribute($this->options['woocommerce_zap_global_description_attribute']);
			} else if($this->options['woocommerce_zap_global_description'] == 'long') {
				$node->DETAILS 	= $product->get_description();
			} else if($this->options['woocommerce_zap_global_description'] == 'short') {
				$node->DETAILS 	= $product->get_short_description();
			} else {
				$node->DETAILS 	= "";
			}
			if($product->get_meta( '_woocommerce_zap_product_catalog_number' )) {
				$node->CATALOG_NUMBER	= $product->get_meta( '_woocommerce_zap_product_catalog_number' );
			} else if($product->get_sku() != "") {
				$node->CATALOG_NUMBER 	= $product->get_sku();
			} else {
				$node->CATALOG_NUMBER 	= "";
			}
			$node->CURRENCY 		= 'ILS';
			if($product->get_meta( '_woocommerce_zap_product_price' )) {
				$node->PRICE 			= $product->get_meta( '_woocommerce_zap_product_price' );
			} else {
				$node->PRICE 	= $product->get_price();
			} 
			if($product->get_meta( '_woocommerce_zap_shipment' )) {
				$node->SHIPMENT_COST 	= $product->get_meta( '_woocommerce_zap_shipment' );
			} else if($this->options['woocommerce_zap_force_shipping_method']) {
				$package = $this->options['woocommerce_zap_force_shipping_method'];
				//WC()->shipping()->calculate_shipping_for_package($this->options['woocommerce_zap_force_shipping_method']);
				//$shipping_methods = WC()->shipping()->load_shipping_methods();
				$delivery_zones = WC_Shipping_Zones::get_zones();
				foreach ((array) $delivery_zones as $key => $the_zone ) {
					//var_dump($the_zone['id']);
				  foreach ($the_zone['zone_locations'] as $zone_location) {
					  if($zone_location->code == 'IL') {
						  $default_zone = new WC_Shipping_Zone($the_zone['id']);
					  }
				  }
				
				}
				if(!$default_zone) {
					$default_zone = new WC_Shipping_Zone(0);
				}
				//$default_zone = new WC_Shipping_Zone(0);
		 		$shipping_methods = $default_zone->get_shipping_methods();
				//$shipping_methods = WC()->shipping->packages;
				//var_dump($shipping_methods);
				//if($shipping_methods[$package]->rates) {
					foreach ($shipping_methods as $shipping_method) {
						if($this->options['woocommerce_zap_force_shipping_method'] == $shipping_method->id) {
							if (isset($shipping_method->cost)) {
								$node->SHIPMENT_COST 	= number_format($shipping_method->cost, 2, '.', '');
							}
						}
					}
				//} else {
					//$node->SHIPMENT_COST 	= "";
				//}
				
			} else {
				$node->SHIPMENT_COST 	= "";
			}
			if($product->get_meta( '_woocommerce_zap_size' )) {
				$node->SIZE 			= $product->get_meta( '_woocommerce_zap_size' );
			} else if($this->options['woocommerce_zap_global_size'] == 'attribute') {
				
				$node->SIZE 	= $product->get_attribute($this->options['woocommerce_zap_global_size_attribute']);
			} else if($this->options['woocommerce_zap_global_size'] == 'text') {
				$node->SIZE 	= $this->options['woocommerce_zap_global_size_default'];
			} else {
				$node->SIZE 	= "";
			}
			if($product->get_meta( '_woocommerce_zap_delivery' )) {
				$node->DELIVERY_TIME 			= $product->get_meta( '_woocommerce_zap_delivery' );
			} else if($this->options['woocommerce_zap_global_delivery'] == 'attribute') {
				$node->DELIVERY_TIME 	= $product->get_attribute($this->options['woocommerce_zap_global_delivery_attribute']);
			} else if($this->options['woocommerce_zap_global_delivery'] == 'text') {
				$node->DELIVERY_TIME 	= $this->options['woocommerce_zap_global_delivery_default'];
			} else {
				$node->DELIVERY_TIME 	= "";
			}
			if($product->get_meta( '_woocommerce_zap_manufacturer' )) {
				$node->MANUFACTURER 			= $product->get_meta( '_woocommerce_zap_manufacturer' );
			} else if($this->options['woocommerce_zap_global_manufacturer'] == 'attribute') {
				$node->MANUFACTURER 	= $product->get_attribute($this->options['woocommerce_zap_global_manufacturer_attribute']);
			} else if($this->options['woocommerce_zap_global_manufacturer'] == 'text') {
				$node->MANUFACTURER 	= $this->options['woocommerce_zap_global_manufacturer_default'];
			} else {
				$node->MANUFACTURER 	= "";
			}
			
			if($product->get_meta( '_woocommerce_zap_warranty' )) {
				$node->WARRANTY 			= $product->get_meta( '_woocommerce_zap_warranty' );
			} else if($this->options['woocommerce_zap_global_warranty'] == 'attribute') {
				$node->WARRANTY 	= $product->get_attribute($this->options['woocommerce_zap_global_warranty_attribute']);
			} else if($this->options['woocommerce_zap_global_warranty'] == 'text') {
				$node->WARRANTY 	= $this->options['woocommerce_zap_global_warranty_default'];
			} else {
				$node->WARRANTY 	= "";
			}
			if($product->get_meta( '_woocommerce_zap_image' )) {
				$node->IMAGE 			= $product->get_meta( '_woocommerce_zap_image' );
			} else {
				$node->IMAGE 			= $product->get_image_id() ? wp_get_attachment_url( $product->get_image_id() ) : wc_placeholder_img_src();
			}
			$node->TAX 				= 1;
			
			/**
			 * Fires after each node properties have been set.
			 */
			do_action_ref_array( 'woocommerce_zap_mirror_xml_node', array( &$node, $product, $post ) );
			
			/**
			 * Fires after specific node properties have been set.
			 */
			do_action_ref_array( "woocommerce_zap_mirror_xml_node_{$post->ID}", array( &$node, $product, $post ) );
		}
		
		/**
		 * Fires after XML is complete.
		 */
		do_action_ref_array( 'woocommerce_zap_mirror_xml', array( &$xml, $products ) );
		echo $xml->asXML();
	}

 }
 /**
  * @return woocommerce_zap_Mirror
  */
 function Zap_Mirror_Wisy_Integration() {
 	return Zap_Mirror_Wisy_Integration::instance();
 }
 // Global for backwards compatibility.
 $GLOBALS['cetu_zap_integration'] = Zap_Mirror_Wisy_Integration();
 
 
 
 class Zap_Mirror_Wisy_Integration_Walker extends Walker_Category {
	public $options;
    // copied function from /inlcude/category-template.php and edited as per requirements
    function start_el( &$output, $category, $depth = 0, $args = array(), $id = 0 ) {
        extract($args);
		$this->options = get_option( 'woocommerce_zap_options' );
        $cat_name = esc_attr( $category->name );
		$cat_id = esc_attr( $category->term_id );
        $cat_name = apply_filters( 'list_cats', $cat_name, $category );
        $my_blog_link = get_permalink( $this->options['woocommerce_zap_mirror_page'] ); //this is to return blog url

        //here I edited the link to meet your requirments.
        $link = '<a href="'.$my_blog_link.'?product_cat='.$category->term_id.'" ';

        if ( $use_desc_for_title == 0 || empty($category->description) )
            $link .= 'title="' . esc_attr( sprintf(__( 'View all posts filed under %s' ), $cat_name) ) . '"';
        else
            $link .= 'title="' . esc_attr( strip_tags( apply_filters( 'category_description', $category->description, $category ) ) ) . '"';
        $link .= '>';
        $link .= $cat_name . '</a>';

        if ( !empty($feed_image) || !empty($feed) ) {
            $link .= ' ';

            if ( empty($feed_image) )
                $link .= '(';

            $link .= '<a href="' . esc_url( get_term_feed_link( $category->term_id, $category->taxonomy, $feed_type ) ) . '"';

            if ( empty($feed) ) {
                $alt = ' alt="' . sprintf(__( 'Feed for all posts filed under %s' ), $cat_name ) . '"';
            } else {
                $title = ' title="' . $feed . '"';
                $alt = ' alt="' . $feed . '"';
                $name = $feed;
                $link .= $title;
            }

            $link .= '>';

            if ( empty($feed_image) )
                $link .= $name;
            else
                $link .= "<img src='$feed_image'$alt$title" . ' />';

            $link .= '</a>';

            if ( empty($feed_image) )
                $link .= ')';
        }

        if ( !empty($show_count) )
            $link .= ' (' . intval($category->count) . ')';

        if ( 'list' == $args['style'] ) {
            $output .= "\t<li";
            $class = 'cat-item cat-item-' . $category->term_id;
            if ( !empty($current_category) ) {
                $_current_category = get_term( $current_category, $category->taxonomy );
                if ( $category->term_id == $current_category )
                    $class .=  ' current-cat';
                elseif ( $category->term_id == $_current_category->parent )
                    $class .=  ' current-cat-parent';
            }
            $output .=  ' class="' . $class . '"';
            $output .= ">$link\n";
        } else {
            $output .= "\t$link<br />\n";
        }
    }

}